@@ -22,6 +22,7 @@ from docker.types import Mount
 from lean.click import LeanCommand, PathParameter
 from lean.constants import DEFAULT_ENGINE_IMAGE, PROJECT_CONFIG_FILE_NAME
 from lean.container import container
+from lean.models.errors import MoreInfoError
 
 
 def _find_project_directory(backtest_file: Path) -> Optional[Path]:
@@ -32,7 +33,7 @@ def _find_project_directory(backtest_file: Path) -> Optional[Path]:
     """
     current_directory = backtest_file.parent
 
-    # Loop until we find the root directory ("/")
+    # Loop until we find the root directory
     while current_directory != current_directory.parent:
         if (current_directory / PROJECT_CONFIG_FILE_NAME).is_file():
             return current_directory
@@ -43,11 +44,10 @@ def _find_project_directory(backtest_file: Path) -> Optional[Path]:
 
 
 @click.command(cls=LeanCommand, requires_lean_config=True, requires_docker=True)
-@click.option("--backtest-data-source-file",
+@click.option("--backtest-results",
               type=PathParameter(exists=True, file_okay=True, dir_okay=False),
-              required=True,
               help="Path to the JSON file containing the backtest results")
-@click.option("--live-data-source-file",
+@click.option("--live-results",
               type=PathParameter(exists=True, file_okay=True, dir_okay=False),
               help="Path to the JSON file containing the live trading results")
 @click.option("--report-destination",
@@ -74,8 +74,8 @@ def _find_project_directory(backtest_file: Path) -> Optional[Path]:
               is_flag=True,
               default=False,
               help="Pull the LEAN engine image before running the report creator")
-def report(backtest_data_source_file: Path,
-           live_data_source_file: Optional[Path],
+def report(backtest_results: Optional[Path],
+           live_results: Optional[Path],
            report_destination: Path,
            strategy_name: Optional[str],
            strategy_version: Optional[str],
@@ -87,6 +87,8 @@ def report(backtest_data_source_file: Path,
 
     This runs the LEAN Report Creator in Docker to generate a polished, professional-grade report of a backtest.
 
+    If --backtest-results is not given, a report is generated for the most recent local backtest.
+
     The name, description, and version are optional and will be blank if not given.
 
     If the given backtest data source file is stored in a project directory (or one of its subdirectories, like the
@@ -100,7 +102,27 @@ def report(backtest_data_source_file: Path,
     if report_destination.exists() and not overwrite:
         raise RuntimeError(f"{report_destination} already exists, use --overwrite to overwrite it")
 
-    project_directory = _find_project_directory(backtest_data_source_file)
+    if backtest_results is None:
+        backtest_json_files = list(Path.cwd().rglob("backtests/*/*.json"))
+        result_json_files = [f for f in backtest_json_files if
+                             not f.name.endswith("-order-events.json") and not f.name.endswith("alpha-results.json")]
+
+        if len(result_json_files) == 0:
+            raise MoreInfoError(
+                "Could not find a recent backtest result file, please use the --backtest-results option",
+                "https://www.lean.io/docs/lean-cli/tutorials/generating-reports"
+            )
+
+        backtest_results = sorted(result_json_files, key=lambda f: f.stat().st_mtime, reverse=True)[0]
+
+    logger = container.logger()
+
+    if live_results is None:
+        logger.info(f"Generating a report from '{backtest_results}'")
+    else:
+        logger.info(f"Generating a report from '{backtest_results}' and '{live_results}'")
+
+    project_directory = _find_project_directory(backtest_results)
 
     if project_directory is not None:
         if strategy_name is None:
@@ -118,7 +140,7 @@ def report(backtest_data_source_file: Path,
         "strategy-name": strategy_name or "",
         "strategy-version": strategy_version or "",
         "strategy-description": strategy_description or "",
-        "live-data-source-file": "live-data-source-file.json" if live_data_source_file is not None else "",
+        "live-data-source-file": "live-data-source-file.json" if live_results is not None else "",
         "backtest-data-source-file": "backtest-data-source-file.json",
         "report-destination": "/Results/report.html",
 
@@ -166,7 +188,7 @@ def report(backtest_data_source_file: Path,
                   type="bind",
                   read_only=True),
             Mount(target="/Lean/Report/bin/Debug/backtest-data-source-file.json",
-                  source=str(backtest_data_source_file),
+                  source=str(backtest_results),
                   type="bind",
                   read_only=True)
         ],
@@ -182,9 +204,9 @@ def report(backtest_data_source_file: Path,
         }
     }
 
-    if live_data_source_file is not None:
+    if live_results is not None:
         run_options["mounts"].append(Mount(target="/Lean/Report/bin/Debug/live-data-source-file.json",
-                                           source=str(live_data_source_file),
+                                           source=str(live_results),
                                            type="bind",
                                            read_only=True))
 
@@ -204,7 +226,6 @@ def report(backtest_data_source_file: Path,
     report_destination.parent.mkdir(parents=True, exist_ok=True)
     shutil.copyfile(output_dir / "report.html", report_destination)
 
-    logger = container.logger()
     logger.info(f"Successfully generated report to '{report_destination}'")
 
     if str(engine_image) == DEFAULT_ENGINE_IMAGE and not update:
