@@ -277,11 +277,29 @@ class QCLiveAlgorithmStatus(str, Enum):
     History = "History"
 
 
-class QCLiveAlgorithm(WrappedBaseModel):
+class QCMinimalLiveAlgorithm(WrappedBaseModel):
     projectId: int
     deployId: str
     status: Optional[QCLiveAlgorithmStatus] = None
 
+    def get_url(self) -> str:
+        """Returns the url of the live deployment in the cloud.
+
+        :return: a url which when visited opens an Algorithm Lab tab containing the live deployment
+        """
+        return f"https://www.quantconnect.com/project/{self.projectId}/live"
+
+
+class QCFullLiveAlgorithm(QCMinimalLiveAlgorithm):
+    projectId: int
+    deployId: str
+    status: Optional[QCLiveAlgorithmStatus] = None
+    launched: datetime
+    stopped: Optional[datetime]
+    brokerage: str
+    subscription: str
+    error: str
+
 
 class QCEmailNotificationMethod(WrappedBaseModel):
     address: str
@@ -333,6 +351,7 @@ class QCOrganizationCredit(WrappedBaseModel):
 
 
 class QCOrganizationProductItem(WrappedBaseModel):
+    productId: int
     name: str
     quantity: int
     unitPrice: float
@@ -349,6 +368,13 @@ class QCOrganizationData(WrappedBaseModel):
     current: bool
 
 
+class QCOrganizationMember(WrappedBaseModel):
+    id: int
+    name: str
+    isAdmin: bool
+    email: str
+
+
 class QCFullOrganization(WrappedBaseModel):
     id: str
     name: str
@@ -357,17 +383,18 @@ class QCFullOrganization(WrappedBaseModel):
     credit: QCOrganizationCredit
     products: List[QCOrganizationProduct]
     data: QCOrganizationData
+    members: List[QCOrganizationMember]
 
-    def has_map_factor_files_subscription(self) -> bool:
-        """Returns whether this organization has a map & factor files subscription.
+    def has_security_master_subscription(self) -> bool:
+        """Returns whether this organization has a Security Master subscription.
 
-        :return: True if the organization has a map & factor files subscription, False if not
+        :return: True if the organization has a Security Master subscription, False if not
         """
         data_products_product = next((x for x in self.products if x.name == "Data"), None)
         if data_products_product is None:
             return False
 
-        return any(x.name == "QuantConnect Equity Factor & Map Files" for x in data_products_product.items)
+        return any(x.productId == 37 for x in data_products_product.items)
 
 
 class QCMinimalOrganization(WrappedBaseModel):
